Class: Aws::ResilienceHub::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ResilienceHub::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-resiliencehub/client.rb,
sig/client.rbs
Overview
An API client for ResilienceHub. To construct a client, you need to configure a :region and :credentials.
client = Aws::ResilienceHub::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AcceptResourceGroupingRecommendationsResponseSuccess, _AddDraftAppVersionResourceMappingsResponseSuccess, _BatchUpdateRecommendationStatusResponseSuccess, _CreateAppResponseSuccess, _CreateAppVersionAppComponentResponseSuccess, _CreateAppVersionResourceResponseSuccess, _CreateRecommendationTemplateResponseSuccess, _CreateResiliencyPolicyResponseSuccess, _DeleteAppAssessmentResponseSuccess, _DeleteAppInputSourceResponseSuccess, _DeleteAppResponseSuccess, _DeleteAppVersionAppComponentResponseSuccess, _DeleteAppVersionResourceResponseSuccess, _DeleteRecommendationTemplateResponseSuccess, _DeleteResiliencyPolicyResponseSuccess, _DescribeAppAssessmentResponseSuccess, _DescribeAppResponseSuccess, _DescribeAppVersionAppComponentResponseSuccess, _DescribeAppVersionResourceResponseSuccess, _DescribeAppVersionResourcesResolutionStatusResponseSuccess, _DescribeAppVersionResponseSuccess, _DescribeAppVersionTemplateResponseSuccess, _DescribeDraftAppVersionResourcesImportStatusResponseSuccess, _DescribeMetricsExportResponseSuccess, _DescribeResiliencyPolicyResponseSuccess, _DescribeResourceGroupingRecommendationTaskResponseSuccess, _ImportResourcesToDraftAppVersionResponseSuccess, _ListAlarmRecommendationsResponseSuccess, _ListAppAssessmentComplianceDriftsResponseSuccess, _ListAppAssessmentResourceDriftsResponseSuccess, _ListAppAssessmentsResponseSuccess, _ListAppComponentCompliancesResponseSuccess, _ListAppComponentRecommendationsResponseSuccess, _ListAppInputSourcesResponseSuccess, _ListAppVersionAppComponentsResponseSuccess, _ListAppVersionResourceMappingsResponseSuccess, _ListAppVersionResourcesResponseSuccess, _ListAppVersionsResponseSuccess, _ListAppsResponseSuccess, _ListMetricsResponseSuccess, _ListRecommendationTemplatesResponseSuccess, _ListResiliencyPoliciesResponseSuccess, _ListResourceGroupingRecommendationsResponseSuccess, _ListSopRecommendationsResponseSuccess, _ListSuggestedResiliencyPoliciesResponseSuccess, _ListTagsForResourceResponseSuccess, _ListTestRecommendationsResponseSuccess, _ListUnsupportedAppVersionResourcesResponseSuccess, _PublishAppVersionResponseSuccess, _PutDraftAppVersionTemplateResponseSuccess, _RejectResourceGroupingRecommendationsResponseSuccess, _RemoveDraftAppVersionResourceMappingsResponseSuccess, _ResolveAppVersionResourcesResponseSuccess, _StartAppAssessmentResponseSuccess, _StartMetricsExportResponseSuccess, _StartResourceGroupingRecommendationTaskResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateAppResponseSuccess, _UpdateAppVersionAppComponentResponseSuccess, _UpdateAppVersionResourceResponseSuccess, _UpdateAppVersionResponseSuccess, _UpdateResiliencyPolicyResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#accept_resource_grouping_recommendations(params = {}) ⇒ Types::AcceptResourceGroupingRecommendationsResponse
Accepts the resource grouping recommendations suggested by Resilience Hub for your application.
-
#add_draft_app_version_resource_mappings(params = {}) ⇒ Types::AddDraftAppVersionResourceMappingsResponse
Adds the source of resource-maps to the draft version of an application.
-
#batch_update_recommendation_status(params = {}) ⇒ Types::BatchUpdateRecommendationStatusResponse
Enables you to include or exclude one or more operational recommendations.
-
#create_app(params = {}) ⇒ Types::CreateAppResponse
Creates an Resilience Hub application.
-
#create_app_version_app_component(params = {}) ⇒ Types::CreateAppVersionAppComponentResponse
Creates a new Application Component in the Resilience Hub application.
-
#create_app_version_resource(params = {}) ⇒ Types::CreateAppVersionResourceResponse
Adds a resource to the Resilience Hub application and assigns it to the specified Application Components.
-
#create_recommendation_template(params = {}) ⇒ Types::CreateRecommendationTemplateResponse
Creates a new recommendation template for the Resilience Hub application.
-
#create_resiliency_policy(params = {}) ⇒ Types::CreateResiliencyPolicyResponse
Creates a resiliency policy for an application.
-
#delete_app(params = {}) ⇒ Types::DeleteAppResponse
Deletes an Resilience Hub application.
-
#delete_app_assessment(params = {}) ⇒ Types::DeleteAppAssessmentResponse
Deletes an Resilience Hub application assessment.
-
#delete_app_input_source(params = {}) ⇒ Types::DeleteAppInputSourceResponse
Deletes the input source and all of its imported resources from the Resilience Hub application.
-
#delete_app_version_app_component(params = {}) ⇒ Types::DeleteAppVersionAppComponentResponse
Deletes an Application Component from the Resilience Hub application.
-
#delete_app_version_resource(params = {}) ⇒ Types::DeleteAppVersionResourceResponse
Deletes a resource from the Resilience Hub application.
-
#delete_recommendation_template(params = {}) ⇒ Types::DeleteRecommendationTemplateResponse
Deletes a recommendation template.
-
#delete_resiliency_policy(params = {}) ⇒ Types::DeleteResiliencyPolicyResponse
Deletes a resiliency policy.
-
#describe_app(params = {}) ⇒ Types::DescribeAppResponse
Describes an Resilience Hub application.
-
#describe_app_assessment(params = {}) ⇒ Types::DescribeAppAssessmentResponse
Describes an assessment for an Resilience Hub application.
-
#describe_app_version(params = {}) ⇒ Types::DescribeAppVersionResponse
Describes the Resilience Hub application version.
-
#describe_app_version_app_component(params = {}) ⇒ Types::DescribeAppVersionAppComponentResponse
Describes an Application Component in the Resilience Hub application.
-
#describe_app_version_resource(params = {}) ⇒ Types::DescribeAppVersionResourceResponse
Describes a resource of the Resilience Hub application.
-
#describe_app_version_resources_resolution_status(params = {}) ⇒ Types::DescribeAppVersionResourcesResolutionStatusResponse
Returns the resolution status for the specified resolution identifier for an application version.
-
#describe_app_version_template(params = {}) ⇒ Types::DescribeAppVersionTemplateResponse
Describes details about an Resilience Hub application.
-
#describe_draft_app_version_resources_import_status(params = {}) ⇒ Types::DescribeDraftAppVersionResourcesImportStatusResponse
Describes the status of importing resources to an application version.
-
#describe_metrics_export(params = {}) ⇒ Types::DescribeMetricsExportResponse
Describes the metrics of the application configuration being exported.
-
#describe_resiliency_policy(params = {}) ⇒ Types::DescribeResiliencyPolicyResponse
Describes a specified resiliency policy for an Resilience Hub application.
-
#describe_resource_grouping_recommendation_task(params = {}) ⇒ Types::DescribeResourceGroupingRecommendationTaskResponse
Describes the resource grouping recommendation tasks run by Resilience Hub for your application.
-
#import_resources_to_draft_app_version(params = {}) ⇒ Types::ImportResourcesToDraftAppVersionResponse
Imports resources to Resilience Hub application draft version from different input sources.
-
#list_alarm_recommendations(params = {}) ⇒ Types::ListAlarmRecommendationsResponse
Lists the alarm recommendations for an Resilience Hub application.
-
#list_app_assessment_compliance_drifts(params = {}) ⇒ Types::ListAppAssessmentComplianceDriftsResponse
List of compliance drifts that were detected while running an assessment.
-
#list_app_assessment_resource_drifts(params = {}) ⇒ Types::ListAppAssessmentResourceDriftsResponse
List of resource drifts that were detected while running an assessment.
-
#list_app_assessments(params = {}) ⇒ Types::ListAppAssessmentsResponse
Lists the assessments for an Resilience Hub application.
-
#list_app_component_compliances(params = {}) ⇒ Types::ListAppComponentCompliancesResponse
Lists the compliances for an Resilience Hub Application Component.
-
#list_app_component_recommendations(params = {}) ⇒ Types::ListAppComponentRecommendationsResponse
Lists the recommendations for an Resilience Hub Application Component.
-
#list_app_input_sources(params = {}) ⇒ Types::ListAppInputSourcesResponse
Lists all the input sources of the Resilience Hub application.
-
#list_app_version_app_components(params = {}) ⇒ Types::ListAppVersionAppComponentsResponse
Lists all the Application Components in the Resilience Hub application.
-
#list_app_version_resource_mappings(params = {}) ⇒ Types::ListAppVersionResourceMappingsResponse
Lists how the resources in an application version are mapped/sourced from.
-
#list_app_version_resources(params = {}) ⇒ Types::ListAppVersionResourcesResponse
Lists all the resources in an Resilience Hub application.
-
#list_app_versions(params = {}) ⇒ Types::ListAppVersionsResponse
Lists the different versions for the Resilience Hub applications.
-
#list_apps(params = {}) ⇒ Types::ListAppsResponse
Lists your Resilience Hub applications.
-
#list_metrics(params = {}) ⇒ Types::ListMetricsResponse
Lists the metrics that can be exported.
-
#list_recommendation_templates(params = {}) ⇒ Types::ListRecommendationTemplatesResponse
Lists the recommendation templates for the Resilience Hub applications.
-
#list_resiliency_policies(params = {}) ⇒ Types::ListResiliencyPoliciesResponse
Lists the resiliency policies for the Resilience Hub applications.
-
#list_resource_grouping_recommendations(params = {}) ⇒ Types::ListResourceGroupingRecommendationsResponse
Lists the resource grouping recommendations suggested by Resilience Hub for your application.
-
#list_sop_recommendations(params = {}) ⇒ Types::ListSopRecommendationsResponse
Lists the standard operating procedure (SOP) recommendations for the Resilience Hub applications.
-
#list_suggested_resiliency_policies(params = {}) ⇒ Types::ListSuggestedResiliencyPoliciesResponse
Lists the suggested resiliency policies for the Resilience Hub applications.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for your resources in your Resilience Hub applications.
-
#list_test_recommendations(params = {}) ⇒ Types::ListTestRecommendationsResponse
Lists the test recommendations for the Resilience Hub application.
-
#list_unsupported_app_version_resources(params = {}) ⇒ Types::ListUnsupportedAppVersionResourcesResponse
Lists the resources that are not currently supported in Resilience Hub.
-
#publish_app_version(params = {}) ⇒ Types::PublishAppVersionResponse
Publishes a new version of a specific Resilience Hub application.
-
#put_draft_app_version_template(params = {}) ⇒ Types::PutDraftAppVersionTemplateResponse
Adds or updates the app template for an Resilience Hub application draft version.
-
#reject_resource_grouping_recommendations(params = {}) ⇒ Types::RejectResourceGroupingRecommendationsResponse
Rejects resource grouping recommendations.
-
#remove_draft_app_version_resource_mappings(params = {}) ⇒ Types::RemoveDraftAppVersionResourceMappingsResponse
Removes resource mappings from a draft application version.
-
#resolve_app_version_resources(params = {}) ⇒ Types::ResolveAppVersionResourcesResponse
Resolves the resources for an application version.
-
#start_app_assessment(params = {}) ⇒ Types::StartAppAssessmentResponse
Creates a new application assessment for an application.
-
#start_metrics_export(params = {}) ⇒ Types::StartMetricsExportResponse
Initiates the export task of metrics.
-
#start_resource_grouping_recommendation_task(params = {}) ⇒ Types::StartResourceGroupingRecommendationTaskResponse
Starts grouping recommendation task.
-
#tag_resource(params = {}) ⇒ Struct
Applies one or more tags to a resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from a resource.
-
#update_app(params = {}) ⇒ Types::UpdateAppResponse
Updates an application.
-
#update_app_version(params = {}) ⇒ Types::UpdateAppVersionResponse
Updates the Resilience Hub application version.
-
#update_app_version_app_component(params = {}) ⇒ Types::UpdateAppVersionAppComponentResponse
Updates an existing Application Component in the Resilience Hub application.
-
#update_app_version_resource(params = {}) ⇒ Types::UpdateAppVersionResourceResponse
Updates the resource details in the Resilience Hub application.
-
#update_resiliency_policy(params = {}) ⇒ Types::UpdateResiliencyPolicyResponse
Updates a resiliency policy.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-resiliencehub/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5162 5163 5164 |
# File 'lib/aws-sdk-resiliencehub/client.rb', line 5162 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5165 5166 5167 |
# File 'lib/aws-sdk-resiliencehub/client.rb', line 5165 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#accept_resource_grouping_recommendations(params = {}) ⇒ Types::AcceptResourceGroupingRecommendationsResponse
Accepts the resource grouping recommendations suggested by Resilience Hub for your application.
87 |
# File 'sig/client.rbs', line 87
def accept_resource_grouping_recommendations: (
|
#add_draft_app_version_resource_mappings(params = {}) ⇒ Types::AddDraftAppVersionResourceMappingsResponse
Adds the source of resource-maps to the draft version of an application. During assessment, Resilience Hub will use these resource-maps to resolve the latest physical ID for each resource in the application template. For more information about different types of resources supported by Resilience Hub and how to add them in your application, see Step 2: How is your application managed? in the Resilience Hub User Guide.
104 |
# File 'sig/client.rbs', line 104
def add_draft_app_version_resource_mappings: (
|
#batch_update_recommendation_status(params = {}) ⇒ Types::BatchUpdateRecommendationStatusResponse
Enables you to include or exclude one or more operational recommendations.
133 |
# File 'sig/client.rbs', line 133
def batch_update_recommendation_status: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5135 5136 5137 5138 5139 5140 5141 5142 5143 5144 5145 5146 5147 5148 5149 5150 5151 |
# File 'lib/aws-sdk-resiliencehub/client.rb', line 5135 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ResilienceHub') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-resiliencehub' context[:gem_version] = '1.68.0' Seahorse::Client::Request.new(handlers, context) end |
#create_app(params = {}) ⇒ Types::CreateAppResponse
Creates an Resilience Hub application. An Resilience Hub application is a collection of Amazon Web Services resources structured to prevent and recover Amazon Web Services application disruptions. To describe a Resilience Hub application, you provide an application name, resources from one or more CloudFormation stacks, Resource Groups, Terraform state files, AppRegistry applications, and an appropriate resiliency policy. In addition, you can also add resources that are located on Amazon Elastic Kubernetes Service (Amazon EKS) clusters as optional resources. For more information about the number of resources supported per application, see Service quotas.
After you create an Resilience Hub application, you publish it so that you can run a resiliency assessment on it. You can then use recommendations from the assessment to improve resiliency by running another assessment, comparing results, and then iterating the process until you achieve your goals for recovery time objective (RTO) and recovery point objective (RPO).
157 |
# File 'sig/client.rbs', line 157
def create_app: (
|
#create_app_version_app_component(params = {}) ⇒ Types::CreateAppVersionAppComponentResponse
Creates a new Application Component in the Resilience Hub application.
PublishAppVersion API.
187 |
# File 'sig/client.rbs', line 187
def create_app_version_app_component: (
|
#create_app_version_resource(params = {}) ⇒ Types::CreateAppVersionResourceResponse
Adds a resource to the Resilience Hub application and assigns it to the specified Application Components. If you specify a new Application Component, Resilience Hub will automatically create the Application Component.
-
This API updates the Resilience Hub application draft version. To use this resource for running resiliency assessments, you must publish the Resilience Hub application using the
PublishAppVersionAPI. -
To update application version with new
physicalResourceID, you must callResolveAppVersionResourcesAPI.
204 |
# File 'sig/client.rbs', line 204
def create_app_version_resource: (
|
#create_recommendation_template(params = {}) ⇒ Types::CreateRecommendationTemplateResponse
Creates a new recommendation template for the Resilience Hub application.
229 |
# File 'sig/client.rbs', line 229
def create_recommendation_template: (
|
#create_resiliency_policy(params = {}) ⇒ Types::CreateResiliencyPolicyResponse
Creates a resiliency policy for an application.
rtoInSecs
and rpoInSecs of your resiliency policy. But, while assessing your
application, the lowest possible assessment result is near zero.
Hence, if you provide value zero for rtoInSecs and rpoInSecs, the
estimated workload RTO and estimated workload RPO result will be near
zero and the Compliance status for your application will be set to
Policy breached.
246 |
# File 'sig/client.rbs', line 246
def create_resiliency_policy: (
|
#delete_app(params = {}) ⇒ Types::DeleteAppResponse
Deletes an Resilience Hub application. This is a destructive action that can't be undone.
265 |
# File 'sig/client.rbs', line 265
def delete_app: (
|
#delete_app_assessment(params = {}) ⇒ Types::DeleteAppAssessmentResponse
Deletes an Resilience Hub application assessment. This is a destructive action that can't be undone.
278 |
# File 'sig/client.rbs', line 278
def delete_app_assessment: (
|
#delete_app_input_source(params = {}) ⇒ Types::DeleteAppInputSourceResponse
Deletes the input source and all of its imported resources from the Resilience Hub application.
290 |
# File 'sig/client.rbs', line 290
def delete_app_input_source: (
|
#delete_app_version_app_component(params = {}) ⇒ Types::DeleteAppVersionAppComponentResponse
Deletes an Application Component from the Resilience Hub application.
PublishAppVersion
API.
- You will not be able to delete an Application Component if it has resources associated with it.
311 |
# File 'sig/client.rbs', line 311
def delete_app_version_app_component: (
|
#delete_app_version_resource(params = {}) ⇒ Types::DeleteAppVersionResourceResponse
Deletes a resource from the Resilience Hub application.
UpdateAppVersionResource
API.
-
This action has no effect outside Resilience Hub.
-
This API updates the Resilience Hub application draft version. To use this resource for running resiliency assessments, you must publish the Resilience Hub application using the
PublishAppVersionAPI.
325 |
# File 'sig/client.rbs', line 325
def delete_app_version_resource: (
|
#delete_recommendation_template(params = {}) ⇒ Types::DeleteRecommendationTemplateResponse
Deletes a recommendation template. This is a destructive action that can't be undone.
348 |
# File 'sig/client.rbs', line 348
def delete_recommendation_template: (
|
#delete_resiliency_policy(params = {}) ⇒ Types::DeleteResiliencyPolicyResponse
Deletes a resiliency policy. This is a destructive action that can't be undone.
359 |
# File 'sig/client.rbs', line 359
def delete_resiliency_policy: (
|
#describe_app(params = {}) ⇒ Types::DescribeAppResponse
Describes an Resilience Hub application.
370 |
# File 'sig/client.rbs', line 370
def describe_app: (
|
#describe_app_assessment(params = {}) ⇒ Types::DescribeAppAssessmentResponse
Describes an assessment for an Resilience Hub application.
380 |
# File 'sig/client.rbs', line 380
def describe_app_assessment: (
|
#describe_app_version(params = {}) ⇒ Types::DescribeAppVersionResponse
Describes the Resilience Hub application version.
392 |
# File 'sig/client.rbs', line 392
def describe_app_version: (
|
#describe_app_version_app_component(params = {}) ⇒ Types::DescribeAppVersionAppComponentResponse
Describes an Application Component in the Resilience Hub application.
405 |
# File 'sig/client.rbs', line 405
def describe_app_version_app_component: (
|
#describe_app_version_resource(params = {}) ⇒ Types::DescribeAppVersionResourceResponse
Describes a resource of the Resilience Hub application.
-
resourceName -
logicalResourceId -
physicalResourceId(Along withphysicalResourceId, you can also provideawsAccountId, andawsRegion)
419 |
# File 'sig/client.rbs', line 419
def describe_app_version_resource: (
|
#describe_app_version_resources_resolution_status(params = {}) ⇒ Types::DescribeAppVersionResourcesResolutionStatusResponse
Returns the resolution status for the specified resolution identifier
for an application version. If resolutionId is not specified, the
current resolution status is returned.
445 |
# File 'sig/client.rbs', line 445
def describe_app_version_resources_resolution_status: (
|
#describe_app_version_template(params = {}) ⇒ Types::DescribeAppVersionTemplateResponse
Describes details about an Resilience Hub application.
459 |
# File 'sig/client.rbs', line 459
def describe_app_version_template: (
|
#describe_draft_app_version_resources_import_status(params = {}) ⇒ Types::DescribeDraftAppVersionResourcesImportStatusResponse
Describes the status of importing resources to an application version.
ResourceImportStatusNotFoundAppMetadataException, you must call
importResourcesToDraftAppVersion after creating the application and
before calling describeDraftAppVersionResourcesImportStatus to
obtain the status.
475 |
# File 'sig/client.rbs', line 475
def describe_draft_app_version_resources_import_status: (
|
#describe_metrics_export(params = {}) ⇒ Types::DescribeMetricsExportResponse
Describes the metrics of the application configuration being exported.
488 |
# File 'sig/client.rbs', line 488
def describe_metrics_export: (
|
#describe_resiliency_policy(params = {}) ⇒ Types::DescribeResiliencyPolicyResponse
Describes a specified resiliency policy for an Resilience Hub application. The returned policy object includes creation time, data location constraints, the Amazon Resource Name (ARN) for the policy, tags, tier, and more.
498 |
# File 'sig/client.rbs', line 498
def describe_resiliency_policy: (
|
#describe_resource_grouping_recommendation_task(params = {}) ⇒ Types::DescribeResourceGroupingRecommendationTaskResponse
Describes the resource grouping recommendation tasks run by Resilience Hub for your application.
510 |
# File 'sig/client.rbs', line 510
def describe_resource_grouping_recommendation_task: (
|
#import_resources_to_draft_app_version(params = {}) ⇒ Types::ImportResourcesToDraftAppVersionResponse
Imports resources to Resilience Hub application draft version from different input sources. For more information about the input sources supported by Resilience Hub, see Discover the structure and describe your Resilience Hub application.
526 |
# File 'sig/client.rbs', line 526
def import_resources_to_draft_app_version: (
|
#list_alarm_recommendations(params = {}) ⇒ Types::ListAlarmRecommendationsResponse
Lists the alarm recommendations for an Resilience Hub application.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
550 |
# File 'sig/client.rbs', line 550
def list_alarm_recommendations: (
|
#list_app_assessment_compliance_drifts(params = {}) ⇒ Types::ListAppAssessmentComplianceDriftsResponse
List of compliance drifts that were detected while running an assessment.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
563 |
# File 'sig/client.rbs', line 563
def list_app_assessment_compliance_drifts: (
|
#list_app_assessment_resource_drifts(params = {}) ⇒ Types::ListAppAssessmentResourceDriftsResponse
List of resource drifts that were detected while running an assessment.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
576 |
# File 'sig/client.rbs', line 576
def list_app_assessment_resource_drifts: (
|
#list_app_assessments(params = {}) ⇒ Types::ListAppAssessmentsResponse
Lists the assessments for an Resilience Hub application. You can use request parameters to refine the results for the response object.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
589 |
# File 'sig/client.rbs', line 589
def list_app_assessments: (
|
#list_app_component_compliances(params = {}) ⇒ Types::ListAppComponentCompliancesResponse
Lists the compliances for an Resilience Hub Application Component.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
607 |
# File 'sig/client.rbs', line 607
def list_app_component_compliances: (
|
#list_app_component_recommendations(params = {}) ⇒ Types::ListAppComponentRecommendationsResponse
Lists the recommendations for an Resilience Hub Application Component.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
620 |
# File 'sig/client.rbs', line 620
def list_app_component_recommendations: (
|
#list_app_input_sources(params = {}) ⇒ Types::ListAppInputSourcesResponse
Lists all the input sources of the Resilience Hub application. For more information about the input sources supported by Resilience Hub, see Discover the structure and describe your Resilience Hub application.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
633 |
# File 'sig/client.rbs', line 633
def list_app_input_sources: (
|
#list_app_version_app_components(params = {}) ⇒ Types::ListAppVersionAppComponentsResponse
Lists all the Application Components in the Resilience Hub application.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
649 |
# File 'sig/client.rbs', line 649
def list_app_version_app_components: (
|
#list_app_version_resource_mappings(params = {}) ⇒ Types::ListAppVersionResourceMappingsResponse
Lists how the resources in an application version are mapped/sourced from. Mappings can be physical resource identifiers, CloudFormation stacks, resource-groups, or an application registry app.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
663 |
# File 'sig/client.rbs', line 663
def list_app_version_resource_mappings: (
|
#list_app_version_resources(params = {}) ⇒ Types::ListAppVersionResourcesResponse
Lists all the resources in an Resilience Hub application.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
678 |
# File 'sig/client.rbs', line 678
def list_app_version_resources: (
|
#list_app_versions(params = {}) ⇒ Types::ListAppVersionsResponse
Lists the different versions for the Resilience Hub applications.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
693 |
# File 'sig/client.rbs', line 693
def list_app_versions: (
|
#list_apps(params = {}) ⇒ Types::ListAppsResponse
Lists your Resilience Hub applications.
An error occurred (ValidationException) when calling the ListApps operation: Only one filter is supported for this operation.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
708 |
# File 'sig/client.rbs', line 708
def list_apps: (
|
#list_metrics(params = {}) ⇒ Types::ListMetricsResponse
Lists the metrics that can be exported.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
726 |
# File 'sig/client.rbs', line 726
def list_metrics: (
|
#list_recommendation_templates(params = {}) ⇒ Types::ListRecommendationTemplatesResponse
Lists the recommendation templates for the Resilience Hub applications.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
758 |
# File 'sig/client.rbs', line 758
def list_recommendation_templates: (
|
#list_resiliency_policies(params = {}) ⇒ Types::ListResiliencyPoliciesResponse
Lists the resiliency policies for the Resilience Hub applications.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
775 |
# File 'sig/client.rbs', line 775
def list_resiliency_policies: (
|
#list_resource_grouping_recommendations(params = {}) ⇒ Types::ListResourceGroupingRecommendationsResponse
Lists the resource grouping recommendations suggested by Resilience Hub for your application.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
788 |
# File 'sig/client.rbs', line 788
def list_resource_grouping_recommendations: (
|
#list_sop_recommendations(params = {}) ⇒ Types::ListSopRecommendationsResponse
Lists the standard operating procedure (SOP) recommendations for the Resilience Hub applications.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
801 |
# File 'sig/client.rbs', line 801
def list_sop_recommendations: (
|
#list_suggested_resiliency_policies(params = {}) ⇒ Types::ListSuggestedResiliencyPoliciesResponse
Lists the suggested resiliency policies for the Resilience Hub applications.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
814 |
# File 'sig/client.rbs', line 814
def list_suggested_resiliency_policies: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for your resources in your Resilience Hub applications.
825 |
# File 'sig/client.rbs', line 825
def list_tags_for_resource: (
|
#list_test_recommendations(params = {}) ⇒ Types::ListTestRecommendationsResponse
Lists the test recommendations for the Resilience Hub application.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
836 |
# File 'sig/client.rbs', line 836
def list_test_recommendations: (
|
#list_unsupported_app_version_resources(params = {}) ⇒ Types::ListUnsupportedAppVersionResourcesResponse
Lists the resources that are not currently supported in Resilience Hub. An unsupported resource is a resource that exists in the object that was used to create an app, but is not supported by Resilience Hub.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
850 |
# File 'sig/client.rbs', line 850
def list_unsupported_app_version_resources: (
|
#publish_app_version(params = {}) ⇒ Types::PublishAppVersionResponse
Publishes a new version of a specific Resilience Hub application.
867 |
# File 'sig/client.rbs', line 867
def publish_app_version: (
|
#put_draft_app_version_template(params = {}) ⇒ Types::PutDraftAppVersionTemplateResponse
Adds or updates the app template for an Resilience Hub application draft version.
879 |
# File 'sig/client.rbs', line 879
def put_draft_app_version_template: (
|
#reject_resource_grouping_recommendations(params = {}) ⇒ Types::RejectResourceGroupingRecommendationsResponse
Rejects resource grouping recommendations.
891 |
# File 'sig/client.rbs', line 891
def reject_resource_grouping_recommendations: (
|
#remove_draft_app_version_resource_mappings(params = {}) ⇒ Types::RemoveDraftAppVersionResourceMappingsResponse
Removes resource mappings from a draft application version.
908 |
# File 'sig/client.rbs', line 908
def remove_draft_app_version_resource_mappings: (
|
#resolve_app_version_resources(params = {}) ⇒ Types::ResolveAppVersionResourcesResponse
Resolves the resources for an application version.
927 |
# File 'sig/client.rbs', line 927
def resolve_app_version_resources: (
|
#start_app_assessment(params = {}) ⇒ Types::StartAppAssessmentResponse
Creates a new application assessment for an application.
938 |
# File 'sig/client.rbs', line 938
def start_app_assessment: (
|
#start_metrics_export(params = {}) ⇒ Types::StartMetricsExportResponse
Initiates the export task of metrics.
953 |
# File 'sig/client.rbs', line 953
def start_metrics_export: (
|
#start_resource_grouping_recommendation_task(params = {}) ⇒ Types::StartResourceGroupingRecommendationTaskResponse
Starts grouping recommendation task.
967 |
# File 'sig/client.rbs', line 967
def start_resource_grouping_recommendation_task: (
|
#tag_resource(params = {}) ⇒ Struct
Applies one or more tags to a resource.
976 |
# File 'sig/client.rbs', line 976
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from a resource.
986 |
# File 'sig/client.rbs', line 986
def untag_resource: (
|
#update_app(params = {}) ⇒ Types::UpdateAppResponse
Updates an application.
997 |
# File 'sig/client.rbs', line 997
def update_app: (
|
#update_app_version(params = {}) ⇒ Types::UpdateAppVersionResponse
Updates the Resilience Hub application version.
PublishAppVersion API.
1025 |
# File 'sig/client.rbs', line 1025
def update_app_version: (
|
#update_app_version_app_component(params = {}) ⇒ Types::UpdateAppVersionAppComponentResponse
Updates an existing Application Component in the Resilience Hub application.
PublishAppVersion API.
1038 |
# File 'sig/client.rbs', line 1038
def update_app_version_app_component: (
|
#update_app_version_resource(params = {}) ⇒ Types::UpdateAppVersionResourceResponse
Updates the resource details in the Resilience Hub application.
-
This API updates the Resilience Hub application draft version. To use this resource for running resiliency assessments, you must publish the Resilience Hub application using the
PublishAppVersionAPI. -
To update application version with new
physicalResourceID, you must callResolveAppVersionResourcesAPI.
1054 |
# File 'sig/client.rbs', line 1054
def update_app_version_resource: (
|
#update_resiliency_policy(params = {}) ⇒ Types::UpdateResiliencyPolicyResponse
Updates a resiliency policy.
rtoInSecs
and rpoInSecs of your resiliency policy. But, while assessing your
application, the lowest possible assessment result is near zero.
Hence, if you provide value zero for rtoInSecs and rpoInSecs, the
estimated workload RTO and estimated workload RPO result will be near
zero and the Compliance status for your application will be set to
Policy breached.
1079 |
# File 'sig/client.rbs', line 1079
def update_resiliency_policy: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5155 5156 5157 |
# File 'lib/aws-sdk-resiliencehub/client.rb', line 5155 def waiter_names [] end |