Class: Aws::ResilienceHub::Types::Alarm

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-resiliencehub/types.rb

Overview

Indicates the Amazon CloudWatch alarm detected while running an assessment.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#alarm_arn ⇒ String

Amazon Resource Name (ARN) of the Amazon CloudWatch alarm.

Returns:

  • (String)


174
175
176
177
178
179
# File 'lib/aws-sdk-resiliencehub/types.rb', line 174

class Alarm < Struct.new(
  :alarm_arn,
  :source)
  SENSITIVE = []
  include Aws::Structure
end

#source ⇒ String

Indicates the source of the Amazon CloudWatch alarm. That is, it indicates if the alarm was created using Resilience Hub recommendation (AwsResilienceHub), or if you had created the alarm in Amazon CloudWatch (Customer).

Returns:

  • (String)


174
175
176
177
178
179
# File 'lib/aws-sdk-resiliencehub/types.rb', line 174

class Alarm < Struct.new(
  :alarm_arn,
  :source)
  SENSITIVE = []
  include Aws::Structure
end