Class: Aws::ResilienceHub::Types::AppComponent

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-resiliencehub/types.rb

Overview

Defines an Application Component.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_info ⇒ Hash<String,Array<String>>

Additional configuration parameters for an Resilience Hub application. If you want to implement additionalInfo through the Resilience Hub console rather than using an API call, see Configure the application configuration parameters.

Currently, this parameter accepts a key-value mapping (in a string format) of only one failover region and one associated account.

Key: "failover-regions"

Value: "[{"region":"<REGION>", "accounts":[{"id":"<ACCOUNT_ID>"}]}]"

Returns:

  • (Hash<String,Array<String>>)


640
641
642
643
644
645
646
647
# File 'lib/aws-sdk-resiliencehub/types.rb', line 640

class AppComponent < Struct.new(
  :additional_info,
  :id,
  :name,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#id ⇒ String

Identifier of the Application Component.

Returns:

  • (String)


640
641
642
643
644
645
646
647
# File 'lib/aws-sdk-resiliencehub/types.rb', line 640

class AppComponent < Struct.new(
  :additional_info,
  :id,
  :name,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

Name of the Application Component.

Returns:

  • (String)


640
641
642
643
644
645
646
647
# File 'lib/aws-sdk-resiliencehub/types.rb', line 640

class AppComponent < Struct.new(
  :additional_info,
  :id,
  :name,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#type ⇒ String

The type of Application Component.

Returns:

  • (String)


640
641
642
643
644
645
646
647
# File 'lib/aws-sdk-resiliencehub/types.rb', line 640

class AppComponent < Struct.new(
  :additional_info,
  :id,
  :name,
  :type)
  SENSITIVE = []
  include Aws::Structure
end