Class: Aws::ResilienceHub::Types::AppSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-resiliencehub/types.rb

Overview

Defines an application summary.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#app_arn ⇒ String

Amazon Resource Name (ARN) of the Resilience Hub application. The format for this ARN is: arn:partition:resiliencehub:region:account:app/app-id. For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference guide.

Returns:

  • (String)


807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
# File 'lib/aws-sdk-resiliencehub/types.rb', line 807

class AppSummary < Struct.new(
  :app_arn,
  :assessment_schedule,
  :aws_application_arn,
  :compliance_status,
  :creation_time,
  :description,
  :drift_status,
  :last_app_compliance_evaluation_time,
  :name,
  :resiliency_score,
  :rpo_in_secs,
  :rto_in_secs,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#assessment_schedule ⇒ String

Assessment execution schedule with 'Daily' or 'Disabled' values.

Returns:

  • (String)


807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
# File 'lib/aws-sdk-resiliencehub/types.rb', line 807

class AppSummary < Struct.new(
  :app_arn,
  :assessment_schedule,
  :aws_application_arn,
  :compliance_status,
  :creation_time,
  :description,
  :drift_status,
  :last_app_compliance_evaluation_time,
  :name,
  :resiliency_score,
  :rpo_in_secs,
  :rto_in_secs,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#aws_application_arn ⇒ String

Amazon Resource Name (ARN) of Resource Groups group that is integrated with an AppRegistry application. For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference guide.

Returns:

  • (String)


807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
# File 'lib/aws-sdk-resiliencehub/types.rb', line 807

class AppSummary < Struct.new(
  :app_arn,
  :assessment_schedule,
  :aws_application_arn,
  :compliance_status,
  :creation_time,
  :description,
  :drift_status,
  :last_app_compliance_evaluation_time,
  :name,
  :resiliency_score,
  :rpo_in_secs,
  :rto_in_secs,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#compliance_status ⇒ String

The current status of compliance for the resiliency policy.

Returns:

  • (String)


807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
# File 'lib/aws-sdk-resiliencehub/types.rb', line 807

class AppSummary < Struct.new(
  :app_arn,
  :assessment_schedule,
  :aws_application_arn,
  :compliance_status,
  :creation_time,
  :description,
  :drift_status,
  :last_app_compliance_evaluation_time,
  :name,
  :resiliency_score,
  :rpo_in_secs,
  :rto_in_secs,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#creation_time ⇒ Time

Date and time when the app was created.

Returns:

  • (Time)


807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
# File 'lib/aws-sdk-resiliencehub/types.rb', line 807

class AppSummary < Struct.new(
  :app_arn,
  :assessment_schedule,
  :aws_application_arn,
  :compliance_status,
  :creation_time,
  :description,
  :drift_status,
  :last_app_compliance_evaluation_time,
  :name,
  :resiliency_score,
  :rpo_in_secs,
  :rto_in_secs,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

The optional description for an app.

Returns:

  • (String)


807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
# File 'lib/aws-sdk-resiliencehub/types.rb', line 807

class AppSummary < Struct.new(
  :app_arn,
  :assessment_schedule,
  :aws_application_arn,
  :compliance_status,
  :creation_time,
  :description,
  :drift_status,
  :last_app_compliance_evaluation_time,
  :name,
  :resiliency_score,
  :rpo_in_secs,
  :rto_in_secs,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#drift_status ⇒ String

Indicates if compliance drifts (deviations) were detected while running an assessment for your application.

Returns:

  • (String)


807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
# File 'lib/aws-sdk-resiliencehub/types.rb', line 807

class AppSummary < Struct.new(
  :app_arn,
  :assessment_schedule,
  :aws_application_arn,
  :compliance_status,
  :creation_time,
  :description,
  :drift_status,
  :last_app_compliance_evaluation_time,
  :name,
  :resiliency_score,
  :rpo_in_secs,
  :rto_in_secs,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#last_app_compliance_evaluation_time ⇒ Time

Date and time of the most recent compliance evaluation.

Returns:

  • (Time)


807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
# File 'lib/aws-sdk-resiliencehub/types.rb', line 807

class AppSummary < Struct.new(
  :app_arn,
  :assessment_schedule,
  :aws_application_arn,
  :compliance_status,
  :creation_time,
  :description,
  :drift_status,
  :last_app_compliance_evaluation_time,
  :name,
  :resiliency_score,
  :rpo_in_secs,
  :rto_in_secs,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the application.

Returns:

  • (String)


807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
# File 'lib/aws-sdk-resiliencehub/types.rb', line 807

class AppSummary < Struct.new(
  :app_arn,
  :assessment_schedule,
  :aws_application_arn,
  :compliance_status,
  :creation_time,
  :description,
  :drift_status,
  :last_app_compliance_evaluation_time,
  :name,
  :resiliency_score,
  :rpo_in_secs,
  :rto_in_secs,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#resiliency_score ⇒ Float

The current resiliency score for the application.

Returns:

  • (Float)


807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
# File 'lib/aws-sdk-resiliencehub/types.rb', line 807

class AppSummary < Struct.new(
  :app_arn,
  :assessment_schedule,
  :aws_application_arn,
  :compliance_status,
  :creation_time,
  :description,
  :drift_status,
  :last_app_compliance_evaluation_time,
  :name,
  :resiliency_score,
  :rpo_in_secs,
  :rto_in_secs,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#rpo_in_secs ⇒ Integer

Recovery Point Objective (RPO) in seconds.

Returns:

  • (Integer)


807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
# File 'lib/aws-sdk-resiliencehub/types.rb', line 807

class AppSummary < Struct.new(
  :app_arn,
  :assessment_schedule,
  :aws_application_arn,
  :compliance_status,
  :creation_time,
  :description,
  :drift_status,
  :last_app_compliance_evaluation_time,
  :name,
  :resiliency_score,
  :rpo_in_secs,
  :rto_in_secs,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#rto_in_secs ⇒ Integer

Recovery Time Objective (RTO) in seconds.

Returns:

  • (Integer)


807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
# File 'lib/aws-sdk-resiliencehub/types.rb', line 807

class AppSummary < Struct.new(
  :app_arn,
  :assessment_schedule,
  :aws_application_arn,
  :compliance_status,
  :creation_time,
  :description,
  :drift_status,
  :last_app_compliance_evaluation_time,
  :name,
  :resiliency_score,
  :rpo_in_secs,
  :rto_in_secs,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

Status of the application.

Returns:

  • (String)


807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
# File 'lib/aws-sdk-resiliencehub/types.rb', line 807

class AppSummary < Struct.new(
  :app_arn,
  :assessment_schedule,
  :aws_application_arn,
  :compliance_status,
  :creation_time,
  :description,
  :drift_status,
  :last_app_compliance_evaluation_time,
  :name,
  :resiliency_score,
  :rpo_in_secs,
  :rto_in_secs,
  :status)
  SENSITIVE = []
  include Aws::Structure
end