Class: Aws::ResilienceHub::Types::DescribeAppVersionTemplateResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-resiliencehub/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#app_arnString

Amazon Resource Name (ARN) of the Resilience Hub application. The format for this ARN is: arn:partition:resiliencehub:region:account:app/app-id. For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference guide.

Returns:

  • (String)


2817
2818
2819
2820
2821
2822
2823
# File 'lib/aws-sdk-resiliencehub/types.rb', line 2817

class DescribeAppVersionTemplateResponse < Struct.new(
  :app_arn,
  :app_template_body,
  :app_version)
  SENSITIVE = []
  include Aws::Structure
end

#app_template_bodyString

A JSON string that provides information about your application structure. To learn more about the appTemplateBody template, see the sample template provided in the Examples section.

The appTemplateBody JSON string has the following structure:

  • resources

    The list of logical resources that must be included in the Resilience Hub application.

    Type: Array

    Don't add the resources that you want to exclude.

    Each resources array item includes the following fields:

  • logicalResourceId

    Logical identifier of the resource.

    Type: Object

    Each logicalResourceId object includes the following fields:

    • identifier

      Identifier of the resource.

      Type: String

    • logicalStackName

      The name of the CloudFormation stack this resource belongs to.

      Type: String

    • resourceGroupName

      The name of the resource group this resource belongs to.

      Type: String

    • terraformSourceName

      The name of the Terraform S3 state file this resource belongs to.

      Type: String

    • eksSourceName

      Name of the Amazon Elastic Kubernetes Service cluster and namespace this resource belongs to.

      This parameter accepts values in "eks-cluster/namespace" format.

      Type: String

  • type

    The type of resource.

    Type: string

  • name

    The name of the resource.

    Type: String

  • additionalInfo

    Additional configuration parameters for an Resilience Hub application. If you want to implement additionalInfo through the Resilience Hub console rather than using an API call, see Configure the application configuration parameters.

    Currently, this parameter accepts a key-value mapping (in a string format) of only one failover region and one associated account.

    Key: "failover-regions"

    Value: "[{"region":"<REGION>", "accounts":[{"id":"<ACCOUNT_ID>"}]}]"

  • appComponents

    List of Application Components that this resource belongs to. If an Application Component is not part of the Resilience Hub application, it will be added.

    Type: Array

    Each appComponents array item includes the following fields:

  • name

    Name of the Application Component.

    Type: String

  • type

    Type of Application Component. For more information about the types of Application Component, see Grouping resources in an AppComponent.

    Type: String

  • resourceNames

    The list of included resources that are assigned to the Application Component.

    Type: Array of strings

  • additionalInfo

    Additional configuration parameters for an Resilience Hub application. If you want to implement additionalInfo through the Resilience Hub console rather than using an API call, see Configure the application configuration parameters.

    Currently, this parameter accepts a key-value mapping (in a string format) of only one failover region and one associated account.

    Key: "failover-regions"

    Value: "[{"region":"<REGION>", "accounts":[{"id":"<ACCOUNT_ID>"}]}]"

  • excludedResources

    The list of logical resource identifiers to be excluded from the application.

    Type: Array

    Don't add the resources that you want to include.

    Each excludedResources array item includes the following fields:

  • logicalResourceIds

    Logical identifier of the resource.

    Type: Object

    You can configure only one of the following fields:

    • logicalStackName

    • resourceGroupName

    • terraformSourceName

    • eksSourceName

    Each logicalResourceIds object includes the following fields:

    • identifier

      Identifier of the resource.

      Type: String

    • logicalStackName

      The name of the CloudFormation stack this resource belongs to.

      Type: String

    • resourceGroupName

      The name of the resource group this resource belongs to.

      Type: String

    • terraformSourceName

      The name of the Terraform S3 state file this resource belongs to.

      Type: String

    • eksSourceName

      Name of the Amazon Elastic Kubernetes Service cluster and namespace this resource belongs to.

      This parameter accepts values in "eks-cluster/namespace" format.

      Type: String

  • version

    Resilience Hub application version.

  • additionalInfo

    Additional configuration parameters for an Resilience Hub application. If you want to implement additionalInfo through the Resilience Hub console rather than using an API call, see Configure the application configuration parameters.

    Currently, this parameter accepts a key-value mapping (in a string format) of only one failover region and one associated account.

    Key: "failover-regions"

    Value: "[{"region":"<REGION>", "accounts":[{"id":"<ACCOUNT_ID>"}]}]"

Returns:

  • (String)


2817
2818
2819
2820
2821
2822
2823
# File 'lib/aws-sdk-resiliencehub/types.rb', line 2817

class DescribeAppVersionTemplateResponse < Struct.new(
  :app_arn,
  :app_template_body,
  :app_version)
  SENSITIVE = []
  include Aws::Structure
end

#app_versionString

The version of the application.

Returns:

  • (String)


2817
2818
2819
2820
2821
2822
2823
# File 'lib/aws-sdk-resiliencehub/types.rb', line 2817

class DescribeAppVersionTemplateResponse < Struct.new(
  :app_arn,
  :app_template_body,
  :app_version)
  SENSITIVE = []
  include Aws::Structure
end