Class: Aws::ResilienceHub::Types::ImportResourcesToDraftAppVersionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ResilienceHub::Types::ImportResourcesToDraftAppVersionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resiliencehub/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#app_arn ⇒ String
Amazon Resource Name (ARN) of the Resilience Hub application.
-
#app_version ⇒ String
The version of the application.
-
#eks_sources ⇒ Array<Types::EksSource>
The input sources of the Amazon Elastic Kubernetes Service resources you have imported.
-
#source_arns ⇒ Array<String>
The Amazon Resource Names (ARNs) for the resources you have imported.
-
#status ⇒ String
Status of the action.
-
#terraform_sources ⇒ Array<Types::TerraformSource>
A list of terraform file s3 URLs you have imported.
Instance Attribute Details
#app_arn ⇒ String
Amazon Resource Name (ARN) of the Resilience Hub application. The
format for this ARN is:
arn:partition:resiliencehub:region:account:app/app-id. For
more information about ARNs, see Amazon Resource Names (ARNs)
in the Amazon Web Services General Reference guide.
3459 3460 3461 3462 3463 3464 3465 3466 3467 3468 |
# File 'lib/aws-sdk-resiliencehub/types.rb', line 3459 class ImportResourcesToDraftAppVersionResponse < Struct.new( :app_arn, :app_version, :eks_sources, :source_arns, :status, :terraform_sources) SENSITIVE = [] include Aws::Structure end |
#app_version ⇒ String
The version of the application.
3459 3460 3461 3462 3463 3464 3465 3466 3467 3468 |
# File 'lib/aws-sdk-resiliencehub/types.rb', line 3459 class ImportResourcesToDraftAppVersionResponse < Struct.new( :app_arn, :app_version, :eks_sources, :source_arns, :status, :terraform_sources) SENSITIVE = [] include Aws::Structure end |
#eks_sources ⇒ Array<Types::EksSource>
The input sources of the Amazon Elastic Kubernetes Service resources you have imported.
3459 3460 3461 3462 3463 3464 3465 3466 3467 3468 |
# File 'lib/aws-sdk-resiliencehub/types.rb', line 3459 class ImportResourcesToDraftAppVersionResponse < Struct.new( :app_arn, :app_version, :eks_sources, :source_arns, :status, :terraform_sources) SENSITIVE = [] include Aws::Structure end |
#source_arns ⇒ Array<String>
The Amazon Resource Names (ARNs) for the resources you have imported.
3459 3460 3461 3462 3463 3464 3465 3466 3467 3468 |
# File 'lib/aws-sdk-resiliencehub/types.rb', line 3459 class ImportResourcesToDraftAppVersionResponse < Struct.new( :app_arn, :app_version, :eks_sources, :source_arns, :status, :terraform_sources) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Status of the action.
3459 3460 3461 3462 3463 3464 3465 3466 3467 3468 |
# File 'lib/aws-sdk-resiliencehub/types.rb', line 3459 class ImportResourcesToDraftAppVersionResponse < Struct.new( :app_arn, :app_version, :eks_sources, :source_arns, :status, :terraform_sources) SENSITIVE = [] include Aws::Structure end |
#terraform_sources ⇒ Array<Types::TerraformSource>
A list of terraform file s3 URLs you have imported.
3459 3460 3461 3462 3463 3464 3465 3466 3467 3468 |
# File 'lib/aws-sdk-resiliencehub/types.rb', line 3459 class ImportResourcesToDraftAppVersionResponse < Struct.new( :app_arn, :app_version, :eks_sources, :source_arns, :status, :terraform_sources) SENSITIVE = [] include Aws::Structure end |