Class: Aws::ResilienceHub::Types::ListMetricsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-resiliencehub/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#conditions ⇒ Array<Types::Condition>

Indicates the list of all the conditions that were applied on the metrics.



4274
4275
4276
4277
4278
4279
4280
4281
4282
4283
# File 'lib/aws-sdk-resiliencehub/types.rb', line 4274

class ListMetricsRequest < Struct.new(
  :conditions,
  :data_source,
  :fields,
  :max_results,
  :next_token,
  :sorts)
  SENSITIVE = []
  include Aws::Structure
end

#data_source ⇒ String

Indicates the data source of the metrics.



4274
4275
4276
4277
4278
4279
4280
4281
4282
4283
# File 'lib/aws-sdk-resiliencehub/types.rb', line 4274

class ListMetricsRequest < Struct.new(
  :conditions,
  :data_source,
  :fields,
  :max_results,
  :next_token,
  :sorts)
  SENSITIVE = []
  include Aws::Structure
end

#fields ⇒ Array<Types::Field>

Indicates the list of fields in the data source.



4274
4275
4276
4277
4278
4279
4280
4281
4282
4283
# File 'lib/aws-sdk-resiliencehub/types.rb', line 4274

class ListMetricsRequest < Struct.new(
  :conditions,
  :data_source,
  :fields,
  :max_results,
  :next_token,
  :sorts)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

Maximum number of results to include in the response. If more results exist than the specified MaxResults value, a token is included in the response so that the remaining results can be retrieved.



4274
4275
4276
4277
4278
4279
4280
4281
4282
4283
# File 'lib/aws-sdk-resiliencehub/types.rb', line 4274

class ListMetricsRequest < Struct.new(
  :conditions,
  :data_source,
  :fields,
  :max_results,
  :next_token,
  :sorts)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

Null, or the token from a previous call to get the next set of results.



4274
4275
4276
4277
4278
4279
4280
4281
4282
4283
# File 'lib/aws-sdk-resiliencehub/types.rb', line 4274

class ListMetricsRequest < Struct.new(
  :conditions,
  :data_source,
  :fields,
  :max_results,
  :next_token,
  :sorts)
  SENSITIVE = []
  include Aws::Structure
end

#sorts ⇒ Array<Types::Sort>

(Optional) Indicates the order in which you want to sort the fields in the metrics. By default, the fields are sorted in the ascending order.



4274
4275
4276
4277
4278
4279
4280
4281
4282
4283
# File 'lib/aws-sdk-resiliencehub/types.rb', line 4274

class ListMetricsRequest < Struct.new(
  :conditions,
  :data_source,
  :fields,
  :max_results,
  :next_token,
  :sorts)
  SENSITIVE = []
  include Aws::Structure
end