Class: Aws::ResilienceHub::Types::ListTestRecommendationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-resiliencehub/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#assessment_arn ⇒ String

Amazon Resource Name (ARN) of the assessment. The format for this ARN is: arn:partition:resiliencehub:region:account:app-assessment/app-id. For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference guide.

Returns:

  • (String)


4617
4618
4619
4620
4621
4622
4623
# File 'lib/aws-sdk-resiliencehub/types.rb', line 4617

class ListTestRecommendationsRequest < Struct.new(
  :assessment_arn,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

Maximum number of results to include in the response. If more results exist than the specified MaxResults value, a token is included in the response so that the remaining results can be retrieved.

Returns:

  • (Integer)


4617
4618
4619
4620
4621
4622
4623
# File 'lib/aws-sdk-resiliencehub/types.rb', line 4617

class ListTestRecommendationsRequest < Struct.new(
  :assessment_arn,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

Null, or the token from a previous call to get the next set of results.

Returns:

  • (String)


4617
4618
4619
4620
4621
4622
4623
# File 'lib/aws-sdk-resiliencehub/types.rb', line 4617

class ListTestRecommendationsRequest < Struct.new(
  :assessment_arn,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end