Class: Aws::ResilienceHub::Types::TestRecommendation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-resiliencehub/types.rb

Overview

Defines a test recommendation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#app_component_id ⇒ String

Indicates the identifier of the AppComponent.

Returns:

  • (String)


6439
6440
6441
6442
6443
6444
6445
6446
6447
6448
6449
6450
6451
6452
6453
6454
6455
# File 'lib/aws-sdk-resiliencehub/types.rb', line 6439

class TestRecommendation < Struct.new(
  :app_component_id,
  :app_component_name,
  :depends_on_alarms,
  :description,
  :intent,
  :items,
  :name,
  :prerequisite,
  :recommendation_id,
  :recommendation_status,
  :reference_id,
  :risk,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#app_component_name ⇒ String

Name of the Application Component.

Returns:

  • (String)


6439
6440
6441
6442
6443
6444
6445
6446
6447
6448
6449
6450
6451
6452
6453
6454
6455
# File 'lib/aws-sdk-resiliencehub/types.rb', line 6439

class TestRecommendation < Struct.new(
  :app_component_id,
  :app_component_name,
  :depends_on_alarms,
  :description,
  :intent,
  :items,
  :name,
  :prerequisite,
  :recommendation_id,
  :recommendation_status,
  :reference_id,
  :risk,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#depends_on_alarms ⇒ Array<String>

A list of recommended alarms that are used in the test and must be exported before or with the test.

Returns:

  • (Array<String>)


6439
6440
6441
6442
6443
6444
6445
6446
6447
6448
6449
6450
6451
6452
6453
6454
6455
# File 'lib/aws-sdk-resiliencehub/types.rb', line 6439

class TestRecommendation < Struct.new(
  :app_component_id,
  :app_component_name,
  :depends_on_alarms,
  :description,
  :intent,
  :items,
  :name,
  :prerequisite,
  :recommendation_id,
  :recommendation_status,
  :reference_id,
  :risk,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

Description for the test recommendation.

Returns:

  • (String)


6439
6440
6441
6442
6443
6444
6445
6446
6447
6448
6449
6450
6451
6452
6453
6454
6455
# File 'lib/aws-sdk-resiliencehub/types.rb', line 6439

class TestRecommendation < Struct.new(
  :app_component_id,
  :app_component_name,
  :depends_on_alarms,
  :description,
  :intent,
  :items,
  :name,
  :prerequisite,
  :recommendation_id,
  :recommendation_status,
  :reference_id,
  :risk,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#intent ⇒ String

Intent of the test recommendation.

Returns:

  • (String)


6439
6440
6441
6442
6443
6444
6445
6446
6447
6448
6449
6450
6451
6452
6453
6454
6455
# File 'lib/aws-sdk-resiliencehub/types.rb', line 6439

class TestRecommendation < Struct.new(
  :app_component_id,
  :app_component_name,
  :depends_on_alarms,
  :description,
  :intent,
  :items,
  :name,
  :prerequisite,
  :recommendation_id,
  :recommendation_status,
  :reference_id,
  :risk,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#items ⇒ Array<Types::RecommendationItem>

The test recommendation items.

Returns:



6439
6440
6441
6442
6443
6444
6445
6446
6447
6448
6449
6450
6451
6452
6453
6454
6455
# File 'lib/aws-sdk-resiliencehub/types.rb', line 6439

class TestRecommendation < Struct.new(
  :app_component_id,
  :app_component_name,
  :depends_on_alarms,
  :description,
  :intent,
  :items,
  :name,
  :prerequisite,
  :recommendation_id,
  :recommendation_status,
  :reference_id,
  :risk,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

Name of the test recommendation.

Returns:

  • (String)


6439
6440
6441
6442
6443
6444
6445
6446
6447
6448
6449
6450
6451
6452
6453
6454
6455
# File 'lib/aws-sdk-resiliencehub/types.rb', line 6439

class TestRecommendation < Struct.new(
  :app_component_id,
  :app_component_name,
  :depends_on_alarms,
  :description,
  :intent,
  :items,
  :name,
  :prerequisite,
  :recommendation_id,
  :recommendation_status,
  :reference_id,
  :risk,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#prerequisite ⇒ String

Prerequisite of the test recommendation.

Returns:

  • (String)


6439
6440
6441
6442
6443
6444
6445
6446
6447
6448
6449
6450
6451
6452
6453
6454
6455
# File 'lib/aws-sdk-resiliencehub/types.rb', line 6439

class TestRecommendation < Struct.new(
  :app_component_id,
  :app_component_name,
  :depends_on_alarms,
  :description,
  :intent,
  :items,
  :name,
  :prerequisite,
  :recommendation_id,
  :recommendation_status,
  :reference_id,
  :risk,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#recommendation_id ⇒ String

Identifier for the test recommendation.

Returns:

  • (String)


6439
6440
6441
6442
6443
6444
6445
6446
6447
6448
6449
6450
6451
6452
6453
6454
6455
# File 'lib/aws-sdk-resiliencehub/types.rb', line 6439

class TestRecommendation < Struct.new(
  :app_component_id,
  :app_component_name,
  :depends_on_alarms,
  :description,
  :intent,
  :items,
  :name,
  :prerequisite,
  :recommendation_id,
  :recommendation_status,
  :reference_id,
  :risk,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#recommendation_status ⇒ String

Status of the recommended test.

Returns:

  • (String)


6439
6440
6441
6442
6443
6444
6445
6446
6447
6448
6449
6450
6451
6452
6453
6454
6455
# File 'lib/aws-sdk-resiliencehub/types.rb', line 6439

class TestRecommendation < Struct.new(
  :app_component_id,
  :app_component_name,
  :depends_on_alarms,
  :description,
  :intent,
  :items,
  :name,
  :prerequisite,
  :recommendation_id,
  :recommendation_status,
  :reference_id,
  :risk,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#reference_id ⇒ String

Reference identifier for the test recommendation.

Returns:

  • (String)


6439
6440
6441
6442
6443
6444
6445
6446
6447
6448
6449
6450
6451
6452
6453
6454
6455
# File 'lib/aws-sdk-resiliencehub/types.rb', line 6439

class TestRecommendation < Struct.new(
  :app_component_id,
  :app_component_name,
  :depends_on_alarms,
  :description,
  :intent,
  :items,
  :name,
  :prerequisite,
  :recommendation_id,
  :recommendation_status,
  :reference_id,
  :risk,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#risk ⇒ String

Level of risk for this test recommendation.

Returns:

  • (String)


6439
6440
6441
6442
6443
6444
6445
6446
6447
6448
6449
6450
6451
6452
6453
6454
6455
# File 'lib/aws-sdk-resiliencehub/types.rb', line 6439

class TestRecommendation < Struct.new(
  :app_component_id,
  :app_component_name,
  :depends_on_alarms,
  :description,
  :intent,
  :items,
  :name,
  :prerequisite,
  :recommendation_id,
  :recommendation_status,
  :reference_id,
  :risk,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#type ⇒ String

Type of test recommendation.

Returns:

  • (String)


6439
6440
6441
6442
6443
6444
6445
6446
6447
6448
6449
6450
6451
6452
6453
6454
6455
# File 'lib/aws-sdk-resiliencehub/types.rb', line 6439

class TestRecommendation < Struct.new(
  :app_component_id,
  :app_component_name,
  :depends_on_alarms,
  :description,
  :intent,
  :items,
  :name,
  :prerequisite,
  :recommendation_id,
  :recommendation_status,
  :reference_id,
  :risk,
  :type)
  SENSITIVE = []
  include Aws::Structure
end