Class: Aws::ResilienceHub::Types::ListResourceGroupingRecommendationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ResilienceHub::Types::ListResourceGroupingRecommendationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-resiliencehub/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#app_arn ⇒ String
Amazon Resource Name (ARN) of the Resilience Hub application.
-
#max_results ⇒ Integer
Maximum number of grouping recommendations to be displayed per Resilience Hub application.
-
#next_token ⇒ String
Null, or the token from a previous call to get the next set of results.
Instance Attribute Details
#app_arn ⇒ String
Amazon Resource Name (ARN) of the Resilience Hub application. The
format for this ARN is:
arn:partition:resiliencehub:region:account:app/app-id. For
more information about ARNs, see Amazon Resource Names (ARNs)
in the Amazon Web Services General Reference guide.
4444 4445 4446 4447 4448 4449 4450 |
# File 'lib/aws-sdk-resiliencehub/types.rb', line 4444 class ListResourceGroupingRecommendationsRequest < Struct.new( :app_arn, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
Maximum number of grouping recommendations to be displayed per Resilience Hub application.
4444 4445 4446 4447 4448 4449 4450 |
# File 'lib/aws-sdk-resiliencehub/types.rb', line 4444 class ListResourceGroupingRecommendationsRequest < Struct.new( :app_arn, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Null, or the token from a previous call to get the next set of results.
4444 4445 4446 4447 4448 4449 4450 |
# File 'lib/aws-sdk-resiliencehub/types.rb', line 4444 class ListResourceGroupingRecommendationsRequest < Struct.new( :app_arn, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |